@@ -5,10 +5,14 @@ setClass(
                         R.fun = 'function',
                         native.fun = 'character',
                         PACKAGE = 'character',
-                        use = 'integer'
+                        mode = 'integer'
                         )
          )
 
+pomp_native_code <- 2L
+pomp_R_function <- 1L
+pomp_undef_mode <- -1L
+
 ## constructor
 pomp.fun <- function (f = NULL, PACKAGE, proto = NULL) {
   if (missing(PACKAGE)) PACKAGE <- ""
@@ -29,7 +33,7 @@ pomp.fun <- function (f = NULL, PACKAGE, proto = NULL) {
                   R.fun=f,
                   native.fun=character(0),
                   PACKAGE=PACKAGE,
-                  use=1L
+                  mode=pomp_R_function
                   )
   } else if (is.character(f)) {
     retval <- new(
@@ -37,7 +41,7 @@ pomp.fun <- function (f = NULL, PACKAGE, proto = NULL) {
                   R.fun=function(...)stop("unreachable error: please report this bug!"),
                   native.fun=f,
                   PACKAGE=PACKAGE,
-                  use=2L
+                  mode=pomp_native_code
                   )
   } else {
     retval <- new(
@@ -45,7 +49,7 @@ pomp.fun <- function (f = NULL, PACKAGE, proto = NULL) {
                   R.fun=function(...)stop(sQuote(fname)," not specified"),
                   native.fun=character(0),
                   PACKAGE=PACKAGE,
-                  use=-1L
+                  mode=pomp_undef_mode
                   )
   }
   retval
@@ -55,10 +59,10 @@ setMethod(
           'show',
           'pomp.fun',
           function (object) {
-            use <- object@use
-            if (use==1L) {
+            mode <- object@mode
+            if (mode==pomp_R_function) {
               show(object@R.fun)
-            } else if (use==2L) {
+            } else if (mode==pomp_native_code) {
               cat("native function ",sQuote(object@native.fun),sep="")
               if (length(object@PACKAGE)>0)
                 cat(", dynamically loaded from ",sQuote(object@PACKAGE),sep="")
@@ -75,14 +79,18 @@ setMethod(
           function (x, ...) show(x)
           )
 
-get.pomp.fun <- function (object) {
-  use <- object@use
-  if (use==1L) {
-    f <- object@R.fun
-  } else if (use==2L) {
-    f <- getNativeSymbolInfo(name=object@native.fun,PACKAGE=object@PACKAGE)$address
-  } else {
-    stop("function not specified")
-  }
-  list(f,as.integer(use-1))
-}
+get.pomp.fun <- function (object)
+  .Call(get_pomp_fun,object)
+
+
+## get.pomp.fun <- function (object) {
+##   mode <- object@mode
+##   if (mode==1L) {
+##     f <- object@R.fun
+##   } else if (mode==2L) {
+##     f <- getNativeSymbolInfo(name=object@native.fun,PACKAGE=object@PACKAGE)$address
+##   } else {
+##     stop("function not specified")
+##   }
+##   list(f,as.integer(mode-1))
+## }
